@@ -1,4 +1,4 @@
-__version__ = '0.0.11'
+__version__ = '0.0.12'
 
 import evaics.sdk as sdk
 from types import SimpleNamespace
@@ -44,11 +44,13 @@ def get_key_val(key_id):
         return key
 
 
-def mark_node(node, status):
+def mark_node(node, status, info=None):
+    payload = {'status': status}
+    if info is not None:
+        payload['info'] = info
     _d.service.bus.send(
         f'RPL/NODE/{node}',
-        elbus.client.Frame(msgpack.dumps({'status': status}),
-                           tp=elbus.client.OP_PUBLISH))
+        elbus.client.Frame(msgpack.dumps(payload), tp=elbus.client.OP_PUBLISH))
 
 
 def jreq(id, method, params=None):
@@ -293,7 +295,12 @@ class LegacyNode:
                 elbus.client.Frame(msgpack.dumps(inventory),
                                    tp=elbus.client.OP_PUBLISH))
             self.online = True
-            mark_node(self.id, 'online')
+            mark_node(self.id,
+                      'online',
+                      info={
+                          'build': self.build,
+                          'version': self.version
+                      })
         except:
             sdk.log_traceback()
             self.online = False
